==> apt-cacher-ng_0.5.14.tar.gz: apt-cacher-ng-0.5.14/source/acfg_defaults.cc <==

// some variable instances with default values 
// shared among different applications

#include "config.h"
#include "meta.h"
#include "acfg.h"

using namespace MYSTD;

namespace acfg {

#if defined(__CYGWIN32__) || defined(__CYGWIN__)
#warning Cygwin seems to have an ancient regex engine which does not distuinguish between greedy and non-greedy repetition, and defaults to non-greedy
#define INFOLDER "(^|.*/)"
#else
#define INFOLDER "(^|.*?/)"
#endif


// always the same
string cachedir("/var/tmp"), logdir("/var/tmp"), fifopath, pidfile, reportpage,
confdir, adminauth, bindaddr, mirrorsrcs;

#define COMPRLIST "(\\.gz|\\.bz2|\\.lzma|\\.xz)"
#define COMPONENT_OPTIONAL "(-[a-z0-9-])"
#define PARANOIASOURCE "(\\.orig|\\.debian)"

string pfilepat(".*(\\.d?deb|\\.rpm|\\.dsc|\\.tar"COMPRLIST"(\\.gpg)?"
		"|\\.diff"COMPRLIST"|\\.jigdo|\\.template|changelog|copyright"
		"|\\.udeb|\\.diff/.*\\.gz|(Devel)?ReleaseAnnouncement(\\?.*)?"
    "|[a-f0-9]+-(susedata|updateinfo|primary|deltainfo).xml.gz" //opensuse, index data, hash in filename
		"|fonts/final/[a-z]+32.exe$" // msttcorefonts
		"|/dists/.*/installer-[^/]+/[0-9][^/]+/images/.*" // d-i stuff with revision
")$");

string vfilepat( INFOLDER
		"(Index|Packages"COMPRLIST"?|Release|Release\\.gpg|"
		"Sources"COMPRLIST"?|release|index\\.db-.*\\.gz|Contents-[^/]*"COMPRLIST
		"|pkglist[^/]*\\.bz2|rclist[^/]*\\.bz2|/meta-release[^/]*|Translation[^/]*"COMPRLIST
		"|MD5SUMS|SHA1SUMS" // d-i stuff
		"|((setup|setup-legacy)(\\.ini|\\.bz2|\\.hint)(\\.sig)?)|mirrors\\.lst" // cygwin
		"|repo(index|md)\\.xml(\\.asc|\\.key)?|directory\\.yast" // opensuse
		"|products|content(\\.asc|\\.key)?|media" // opensuse 2, are they important?
		"|packages\\.[a-zA-Z][a-zA-Z]\\.gz|info\\.txt|license\\.tar\\.gz|license\\.zip" //opensuse
		"|.*\\.db\\.tar\\.gz|.*\\.files\\.tar\\.gz|.*\\.abs\\.tar\\.gz" // Arch Linux
//    "|metalink\\?repo"     "|.*prestodelta\\.xml\\.gz" // fedora core 13, worked in the beginning and then decided to hate me
		")$" // end of filename paterns. Any other some specific URLs?
		"|/dists/.*/installer-[^/]+/[^0-9][^/]+/images/.*"); // d-i stuff but not containing a number (year) in the revision directory (like "current", "beta", ...)

//string wfilepat( VPATPREFIX  "(Release|Release\\.gpg|release|meta-release|Translation[^/]*\\.bz2)$");
//string wfilepat(vfilepat);
string wfilepat(INFOLDER
		"(Release|Release\\.gpg"
		"|(Packages|Sources)"COMPRLIST"?"
		"|Translation[^/]*"COMPRLIST // to be checked, but they should never really go anywhere
		"|MD5SUMS|SHA1SUMS"
		"|.*\\.xml" // SUSE
		"|.*\\.db\\.tar\\.gz|.*\\.files\\.tar\\.gz|.*\\.abs\\.tar\\.gz" // Arch Linux
		"|[a-z]+32.exe"
		")$"
		"|/dists/.*/installer-.*/images/.*");


int offlinemode(false), verboselog(true), stupidfs(false), forcemanaged(false),
extreshhold(20), tpstandbymax(8), tpthreadmax(-1), dirperms(00755), fileperms(00664);

int dnscachetime(1800), dlbufsize(70000), exfailabort(1), exporigin(false), 
logxff(false), oldupdate(false), recompbz2(false), nettimeout(60), updinterval(0), forwardsoap(RESERVED_DEFVAL);

string agentname("Debian Apt-Cacher-NG/" ACVERSION);
string remoteport("80"), port("3142");
string agentheader;

string requestapx("Cache-Control: no-store,no-cache,max-age=0\\r\\n");

#ifdef DEBUG
int debug(3), foreground(true);
//string cachedir("/var/cache/acng"), logdir("/var/log/acng"), fifopath, pidfile;
#else
int debug(0), foreground(false);
#endif

tHttpUrl proxy_info; // abuses path member for auth data

string cacheDirSlash; // guaranteed to have a trailing path separator

}

==> apt-cacher-ng_0.6.3.orig.tar.gz: apt-cacher-ng-0.6.3/source/acfg_defaults.cc <==

// some variable instances with default values 
// shared among different applications

#include "config.h"
#include "meta.h"
#include "acfg.h"

using namespace MYSTD;

namespace acfg {

#if defined(__CYGWIN32__) || defined(__CYGWIN__)
#warning Cygwin seems to have an ancient regex engine which does not distuinguish between greedy and non-greedy repetition, and defaults to non-greedy
#define INFOLDER "(^|.*/)"
#else
#define INFOLDER "(^|.*?/)"
#endif


// always the same
string cachedir("/var/tmp"), logdir("/var/tmp"), fifopath, pidfile, reportpage,
confdir, adminauth, bindaddr, mirrorsrcs;

#define COMPRLIST "(\\.gz|\\.bz2|\\.lzma|\\.xz)"
#define COMPONENT_OPTIONAL "(-[a-z0-9-])"
#define PARANOIASOURCE "(\\.orig|\\.debian)"

string pfilepat(".*(\\.d?deb|\\.rpm|\\.dsc|\\.tar"COMPRLIST"(\\.gpg)?"
		"|\\.diff"COMPRLIST"|\\.jigdo|\\.template|changelog|copyright"
		"|\\.udeb|\\.diff/.*\\.gz|(Devel)?ReleaseAnnouncement(\\?.*)?"
    "|[a-f0-9]+-(susedata|updateinfo|primary|deltainfo).xml.gz" //opensuse, index data, hash in filename
		"|fonts/(final/)?[a-z]+32.exe(\\?download.*)?" // msttcorefonts, fonts/final/comic32.exe /corefonts/comic32.exe plus SF's parameters
		"|/dists/.*/installer-[^/]+/[0-9][^/]+/images/.*" // d-i stuff with revision
")$");

string vfilepat( INFOLDER
		"(Index|Packages"COMPRLIST"?|InRelease|Release|Release\\.gpg|"
		"Sources"COMPRLIST"?|release|index\\.db-.*\\.gz|Contents-[^/]*"COMPRLIST
		"|pkglist[^/]*\\.bz2|rclist[^/]*\\.bz2|/meta-release[^/]*|Translation[^/]*"COMPRLIST
		"|MD5SUMS|SHA1SUMS" // d-i stuff
		"|((setup|setup-legacy)(\\.ini|\\.bz2|\\.hint)(\\.sig)?)|mirrors\\.lst" // cygwin
		"|repo(index|md)\\.xml(\\.asc|\\.key)?|directory\\.yast" // opensuse
		"|products|content(\\.asc|\\.key)?|media" // opensuse 2, are they important?
		"|packages\\.[a-zA-Z][a-zA-Z]\\.gz|info\\.txt|license\\.tar\\.gz|license\\.zip" //opensuse
		"|.*\\.db\\.tar\\.gz|.*\\.files\\.tar\\.gz|.*\\.abs\\.tar\\.gz" // Arch Linux
//    "|metalink\\?repo"     "|.*prestodelta\\.xml\\.gz" // fedora core 13, worked in the beginning and then decided to hate me
		")$" // end of filename paterns. Any other some specific URLs?
		"|/dists/.*/installer-[^/]+/[^0-9][^/]+/images/.*"); // d-i stuff but not containing a number (year) in the revision directory (like "current", "beta", ...)

//string wfilepat( VPATPREFIX  "(Release|Release\\.gpg|release|meta-release|Translation[^/]*\\.bz2)$");
//string wfilepat(vfilepat);
string wfilepat(INFOLDER
		"(Release|InRelease|Release\\.gpg"
		"|(Packages|Sources)"COMPRLIST"?"
		"|Translation[^/]*"COMPRLIST // to be checked, but they should never really go anywhere
		"|MD5SUMS|SHA1SUMS"
		"|.*\\.xml" // SUSE
		"|.*\\.db\\.tar\\.gz|.*\\.files\\.tar\\.gz|.*\\.abs\\.tar\\.gz" // Arch Linux
		"|[a-z]+32.exe"
		")$"
		"|/dists/.*/installer-.*/images/.*");


int offlinemode(false), verboselog(true), stupidfs(false), forcemanaged(false),
extreshhold(20), tpstandbymax(8), tpthreadmax(-1), dirperms(00755), fileperms(00664);

int dnscachetime(1800), dlbufsize(70000), exfailabort(1), exporigin(false), 
logxff(false), oldupdate(false), recompbz2(false), nettimeout(60), updinterval(0), forwardsoap(RESERVED_DEFVAL);

string agentname("Debian Apt-Cacher-NG/" ACVERSION);
string remoteport("80"), port("3142");
string agentheader;

string requestapx;

#ifdef DEBUG
int debug(3), foreground(true);
//string cachedir("/var/cache/acng"), logdir("/var/log/acng"), fifopath, pidfile;
#else
int debug(0), foreground(false);
#endif

tHttpUrl proxy_info; // abuses path member for auth data

string cacheDirSlash; // guaranteed to have a trailing path separator

}
